@@ -275,6 +275,8 @@ class SqliteRecorder(CaseRecorder):
                               "solver_options BLOB, solver_class TEXT)")
 
         self._database_initialized = True
+        if MPI is not None:
+            MPI.COMM_WORLD.barrier()
 
     def _cleanup_abs2meta(self):
         """
