@@ -86,7 +86,7 @@ class SolverInfo(object):
         Returns
         -------
         tuple(str, list)
-            cache of current stack
+            Cache of current stack.
         """
         return (self.prefix, self.stack)
 
@@ -97,7 +97,7 @@ class SolverInfo(object):
         Parameters
         ----------
         cache : tuple(str, list)
-            cache of current stack
+            Cache of current stack.
         """
         self.prefix, self.stack = cache
 
@@ -109,6 +109,11 @@ class Solver(object):
     This class is subclassed by NonlinearSolver and LinearSolver,
     which are in turn subclassed by actual solver implementations.
 
+    Parameters
+    ----------
+    **kwargs : dict of keyword arguments
+        Keyword arguments that will be mapped into the Solver options.
+
     Attributes
     ----------
     _system : <System>
@@ -145,11 +150,6 @@ class Solver(object):
     def __init__(self, **kwargs):
         """
         Initialize all attributes.
-
-        Parameters
-        ----------
-        **kwargs : dict of keyword arguments
-            Keyword arguments that will be mapped into the Solver options.
         """
         self._system = None
         self._depth = 0
@@ -414,7 +414,7 @@ class Solver(object):
 
         Returns
         -------
-        boolean
+        bool
             Flag for indicating child linerization
         """
         return True
@@ -508,6 +508,11 @@ class NonlinearSolver(Solver):
     """
     Base class for nonlinear solvers.
 
+    Parameters
+    ----------
+    **kwargs : dict
+        Options dictionary.
+
     Attributes
     ----------
     _err_cache : dict
@@ -517,11 +522,6 @@ class NonlinearSolver(Solver):
     def __init__(self, **kwargs):
         """
         Initialize all attributes.
-
-        Parameters
-        ----------
-        **kwargs : dict
-            options dictionary.
         """
         super().__init__(**kwargs)
         self._err_cache = OrderedDict()
@@ -768,6 +768,11 @@ class LinearSolver(Solver):
     """
     Base class for linear solvers.
 
+    Parameters
+    ----------
+    **kwargs : dict
+        Options dictionary.
+
     Attributes
     ----------
     _rel_systems : set of str
@@ -779,11 +784,6 @@ class LinearSolver(Solver):
     def __init__(self, **kwargs):
         """
         Initialize all attributes.
-
-        Parameters
-        ----------
-        **kwargs : dict
-            options dictionary.
         """
         self._rel_systems = None
         self._assembled_jac = None
@@ -937,6 +937,11 @@ class LinearSolver(Solver):
 class BlockLinearSolver(LinearSolver):
     """
     A base class for LinearBlockGS and LinearBlockJac.
+
+    Parameters
+    ----------
+    **kwargs : dict
+        Options dictionary.
     """
 
     def _declare_options(self):
