@@ -1,15 +1,10 @@
 """Define the PETSc Transfer class."""
 import numpy as np
 from petsc4py import PETSc
-from itertools import product, chain
 from collections import defaultdict
 
-from openmdao.vectors.transfer import Transfer
 from openmdao.vectors.default_transfer import DefaultTransfer, _merge
 from openmdao.core.constants import INT_DTYPE
-from openmdao.utils.mpi import MPI
-from openmdao.utils.array_utils import convert_neg
-from openmdao.utils.general_utils import _is_slicer_op
 
 _empty_idx_array = np.array([], dtype=INT_DTYPE)
 
